# GNU Solfege - eartraining for GNOME
# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""
This module tries to emulate as much as needed of 
gnome libs to get Solfege running on win32. Of cource
you can use it on a real OS too, but if it is possible,
you really, REALLY want the real thing.
"""
print "****************"
print "using gnome emu"
print "****************"

def program_init(appname, version):
    print "dummy program_init(%s, %s)" % (appname, version)

def program_get():
    class Dummy:
        def parse_args(self):
            print "dummy program.parse_args()"
    return Dummy()
